@@ -1,12 +1,12 @@
 use crate::*;
 
-use bindings::Windows::Win32::SystemServices::{FreeLibrary, GetProcAddress, LoadLibraryA};
+use bindings::Windows::Win32::System::SystemServices::{FreeLibrary, GetProcAddress, LoadLibraryA};
 
 pub fn delay_load(library: &str, function: &str) -> std::result::Result<RawPtr, HRESULT> {
     unsafe {
         let library = LoadLibraryA(library);
 
-        if library == 0 {
+        if library.is_null() {
             return Err(HRESULT::from_thread());
         }
 
